@@ -5,6 +5,7 @@ from collections import defaultdict
 
 from grapheekdb.lib.undef import UNDEFINED
 from grapheekdb.lib.readwrite import GraphReadWrite
+from grapheekdb.lib.nx import GraphNx
 from grapheekdb.lib.validations import check_valid_data
 from grapheekdb.lib.exceptions import GrapheekDataException, GrapheekDataPreparationFailedException, GrapheekIndexAlreadyExistsException
 from grapheekdb.lib.exceptions import GrapheekIndexCreationFailedException, GrapheekIndexRemovalFailedException, GrapheekNoSuchTraversalException
@@ -107,7 +108,7 @@ class DotExport(object):
         edge_collections = []
         if kind == KIND_EDGE:
             # Collecting label, ids and related node ids :
-            edge_node_ids    = set()
+            edge_node_ids = set()
             for edge_id in set(entity_iterator.limit(self.limit)._iterate(on_item=False)):
                 label, src_id, tgt_id = self._edge_struct(edge_id)
                 edge_collections.append((label, src_id, tgt_id))
@@ -118,7 +119,7 @@ class DotExport(object):
                 label = self._node_label(node_id)
                 node_collections.append((node_id, label))
         else:  # KIND_VERTEX
-            node_edge_ids    = set()
+            node_edge_ids = set()
             node_ids = set(entity_iterator.limit(self.limit)._iterate(on_item=False))
             # Collecting label, ids and related edge ids :
             for node_id in node_ids:
@@ -432,11 +433,15 @@ class EntityIterator(object):
         return EntityIterator(self._graph, self._src_kind, {}, limit_iterator(self._iterate(), count), parent=self)
 
     def aka(self, alias):
-        def alias_iterator(entity_iterator, alias):
-            for entity in entity_iterator:
-                self._context[alias] = entity
-                yield entity.get_id()
-        return EntityIterator(self._graph, self._src_kind, {}, alias_iterator(self, alias), parent=self)
+        def alias_iterator(entity_id_iterator, alias):
+            graph = self._graph
+            entity_cache = {}
+            for entity_id in entity_id_iterator:
+                entity = entity_cache.get(entity_id, None)
+                if entity is None:
+                    entity_cache[entity_id] = self._context[alias] = graph._item_from_id(self._src_kind, entity_id)
+                yield entity_id
+        return EntityIterator(self._graph, self._src_kind, {}, alias_iterator(self._iterate(), alias), parent=self)
 
     # Following methods don't return iterator :
 
@@ -797,7 +802,7 @@ class Edge(Entity):
         self._graph._remove_edge(self._entity_id)
 
 
-class BaseGraph(GraphReadWrite):
+class BaseGraph(GraphReadWrite, GraphNx):
 
     def close(self):
         if not self._closed:
