@@ -11,6 +11,7 @@ from grapheekdb.backends.data.keys import KIND_VERTEX, KIND_EDGE
 from grapheekdb.lib.validations import check_valid_data
 
 from grapheekdb.lib.readwrite import GraphReadWrite
+from grapheekdb.lib.nx import GraphNx
 
 from grapheekdb.lib.exceptions import GrapheekException
 from grapheekdb.lib.exceptions import GrapheekDataException
@@ -317,7 +318,7 @@ class ProxyEdge(ProxyEntity):
         super(ProxyEdge, self).__init__(_graph, _edge_id, **data)
 
 
-class ProxyGraph(GraphReadWrite):
+class ProxyGraph(GraphReadWrite, GraphNx):
 
     def __init__(self, address):  # pragma : no cover
         self._address = address
