@@ -11,7 +11,7 @@ def check_valid_value(value):
     if isinstance(value, (BooleanType, FloatType, IntType, LongType, NoneType, StringType, UnicodeType)):
         return True
     elif isinstance(value, ListType):
-        return all([check_valid_data(subvalue) for subvalue in value])
+        return all([check_valid_value(subvalue) for subvalue in value])
     elif isinstance(value, DictType):
         return check_valid_data(value, check_dict=False)
     return False
